@@ -118,6 +118,12 @@ class Breakpoint:
         CHARLIE = 0x10
         DELTA = 0x20
         ECHO = 0x40
+        WATCH = 0x02000000
+        TRACEENABLE = 0x04000000
+        TRACEDATA = 0x08000000
+        TRACEON = 0x10000000
+        TRACEOFF = 0x20000000
+        TRACETRIGGER = 0x40000000
 
     class Type(enum.IntEnum):
         DELETED = 0x00
